@@ -16,13 +16,10 @@ PKG_NAME="avant-window-navigator"
 if which gnome-autogen.sh ; then
   REQUIRED_AUTOMAKE_VERSION=1.9 . gnome-autogen.sh
 else
-  if which intltoolize && which glib-gettextize && which gtkdocize && which autoreconf ; then
+  if which intltoolize && which gtkdocize && which autoreconf ; then
     intltoolize --copy --force --automake || \
       (echo "There was an error in running intltoolize." > /dev/stderr;
        exit 1)
-    glib-gettextize --copy --force || \
-      (echo "There was an error in running glib-gettextize." > /dev/stderr;
-       exit 1)
     gtkdocize --copy || \
       (echo "There was an error in running gtkdocize." > /dev/stderr;
        exit 1)
@@ -35,7 +32,6 @@ else
     echo "   sure the gnome-autogen.sh script is in your \$PATH."
     echo "2. You need to install the following scripts:"
     echo "   * intltool"
-    echo "   * glib-gettextize (usually installed with glib-2.0)"
     echo "   * gtk-doc"
     echo "   * libtool"
     echo "   * automake"
