@@ -9,34 +9,34 @@
 G_BEGIN_DECLS
 
 /* enumerations from "awn-defines.h" */
-GType awn_orientation_get_type (void) G_GNUC_CONST;
-#define AWN_TYPE_ORIENTATION (awn_orientation_get_type())
+GType awn_applet_flags_get_type (void) G_GNUC_CONST;
+#define AWN_TYPE_APPLET_FLAGS (awn_applet_flags_get_type())
+
+GType awn_applet_license_get_type (void) G_GNUC_CONST;
+#define AWN_TYPE_APPLET_LICENSE (awn_applet_license_get_type())
+
+GType awn_path_type_get_type (void) G_GNUC_CONST;
+#define AWN_TYPE_PATH_TYPE (awn_path_type_get_type())
 
 /* enumerations from "awn-cairo-utils.h" */
 GType awn_cairo_round_corners_get_type (void) G_GNUC_CONST;
 #define AWN_TYPE_CAIRO_ROUND_CORNERS (awn_cairo_round_corners_get_type())
 
-/* enumerations from "awn-config-client.h" */
-GType awn_config_value_type_get_type (void) G_GNUC_CONST;
-#define AWN_TYPE_CONFIG_VALUE_TYPE (awn_config_value_type_get_type())
-
-GType awn_config_list_type_get_type (void) G_GNUC_CONST;
-#define AWN_TYPE_CONFIG_LIST_TYPE (awn_config_list_type_get_type())
-
 /* enumerations from "awn-effects.h" */
 GType awn_effect_get_type (void) G_GNUC_CONST;
 #define AWN_TYPE_EFFECT (awn_effect_get_type())
 
+/* enumerations from "awn-overlay.h" */
+GType awn_overlay_align_get_type (void) G_GNUC_CONST;
+#define AWN_TYPE_OVERLAY_ALIGN (awn_overlay_align_get_type())
+
+/* enumerations from "anims/awn-effects-shared.h" */
+GType awn_arrow_type_get_type (void) G_GNUC_CONST;
+#define AWN_TYPE_ARROW_TYPE (awn_arrow_type_get_type())
+
 GType awn_effect_sequence_get_type (void) G_GNUC_CONST;
 #define AWN_TYPE_EFFECT_SEQUENCE (awn_effect_sequence_get_type())
 
-/* enumerations from "awn-vfs.h" */
-GType awn_vfs_monitor_event_get_type (void) G_GNUC_CONST;
-#define AWN_TYPE_VFS_MONITOR_EVENT (awn_vfs_monitor_event_get_type())
-
-GType awn_vfs_monitor_type_get_type (void) G_GNUC_CONST;
-#define AWN_TYPE_VFS_MONITOR_TYPE (awn_vfs_monitor_type_get_type())
-
 G_END_DECLS
 
 #endif /* !__AWN_ENUM_TYPES_H__ */
